_base_ = [
    '../_base_/datasets/gpt.py', '../_base_/models/gpt.py',
    '../_base_/schedules/default_schedule.py', '../_base_/default_runtime.py'
]
